==> kubernetes-model-core-5.8.0-sources.jar: io/fabric8/kubernetes/api/model/PodTemplateListBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PodTemplateListBuilder extends io.fabric8.kubernetes.api.model.PodTemplateListFluentImpl<io.fabric8.kubernetes.api.model.PodTemplateListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.PodTemplateList,io.fabric8.kubernetes.api.model.PodTemplateListBuilder>{
  public PodTemplateListBuilder() {
    this(false);
  }
  public PodTemplateListBuilder(java.lang.Boolean validationEnabled) {
    this(new PodTemplateList(), validationEnabled);
  }
  public PodTemplateListBuilder(io.fabric8.kubernetes.api.model.PodTemplateListFluent<?> fluent) {
    this(fluent, false);
  }
  public PodTemplateListBuilder(io.fabric8.kubernetes.api.model.PodTemplateListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PodTemplateList(), validationEnabled);
  }
  public PodTemplateListBuilder(io.fabric8.kubernetes.api.model.PodTemplateListFluent<?> fluent,io.fabric8.kubernetes.api.model.PodTemplateList instance) {
    this(fluent, instance, false);
  }
  public PodTemplateListBuilder(io.fabric8.kubernetes.api.model.PodTemplateListFluent<?> fluent,io.fabric8.kubernetes.api.model.PodTemplateList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    this.validationEnabled = validationEnabled; 
  }
  public PodTemplateListBuilder(io.fabric8.kubernetes.api.model.PodTemplateList instance) {
    this(instance,false);
  }
  public PodTemplateListBuilder(io.fabric8.kubernetes.api.model.PodTemplateList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.PodTemplateListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.PodTemplateList build() {
    PodTemplateList buildable = new PodTemplateList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PodTemplateListBuilder that = (PodTemplateListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-core-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/PodTemplateListBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class PodTemplateListBuilder extends io.fabric8.kubernetes.api.model.PodTemplateListFluentImpl<io.fabric8.kubernetes.api.model.PodTemplateListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.PodTemplateList,io.fabric8.kubernetes.api.model.PodTemplateListBuilder>{
  public PodTemplateListBuilder() {
    this(false);
  }
  public PodTemplateListBuilder(java.lang.Boolean validationEnabled) {
    this(new PodTemplateList(), validationEnabled);
  }
  public PodTemplateListBuilder(io.fabric8.kubernetes.api.model.PodTemplateListFluent<?> fluent) {
    this(fluent, false);
  }
  public PodTemplateListBuilder(io.fabric8.kubernetes.api.model.PodTemplateListFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new PodTemplateList(), validationEnabled);
  }
  public PodTemplateListBuilder(io.fabric8.kubernetes.api.model.PodTemplateListFluent<?> fluent,io.fabric8.kubernetes.api.model.PodTemplateList instance) {
    this(fluent, instance, false);
  }
  public PodTemplateListBuilder(io.fabric8.kubernetes.api.model.PodTemplateListFluent<?> fluent,io.fabric8.kubernetes.api.model.PodTemplateList instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withItems(instance.getItems()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public PodTemplateListBuilder(io.fabric8.kubernetes.api.model.PodTemplateList instance) {
    this(instance,false);
  }
  public PodTemplateListBuilder(io.fabric8.kubernetes.api.model.PodTemplateList instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withItems(instance.getItems()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.PodTemplateListFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.PodTemplateList build() {
    PodTemplateList buildable = new PodTemplateList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PodTemplateListBuilder that = (PodTemplateListBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
